@@ -1,5 +1,5 @@
 
-#' Get Current Weather Observations of a BOM Station
+#' Get current weather observations of a BOM station
 #'
 #' @param station_name The name of the weather station. Fuzzy string matching
 #' via \code{\link[base]{agrep}} is done.
@@ -15,8 +15,8 @@
 #' used in combination with \var{station_name}, with a warning.
 #' @param emit_latlon_msg Logical. If \code{TRUE} (the default), and
 #' \code{latlon} is selected, a message is emitted before the table is returned
-#' indicating which station was actually used (i.e. which station was found to
-#' be nearest to the given coordinate).
+#' indicating which station was actually used (\emph{i.e.} which station was
+#' found to be nearest to the given coordinate).
 #'
 #' @details
 #' Station names are not consistently named within the Bureau, so
@@ -27,13 +27,14 @@
 #'
 #' Note that the column \code{local_date_time_full} is set to a
 #' \code{POSIXct} object in the local time of the \strong{user}.
-#' For more details see the vignette "Current Weather Fields":\cr
-#' \code{vignette("Current Weather Fields", package = "bomrang")}\cr
+#' For more details see "Appendix 1 - Output from get_current_weather()" in
+#' the \pkg{bomrang} vignette \cr
+#' \code{vignette("bomrang", package = "bomrang")}\cr
 #' for a complete list of fields and units.
 #'
 #' @return A \code{bomrang_tbl} object (extension of a 
 #' \code{\link[base]{data.frame}})  of requested BOM station's current and prior
-#'  72hr data.  For full details of fields and units returned, see Appendix 1
+#'  72hr data. For full details of fields and units returned, see Appendix 1
 #'  in the \pkg{bomrang} vignette, use \cr
 #' \code{vignette("bomrang", package = "bomrang")} to view.
 #' @examples
@@ -49,12 +50,12 @@
 #' }
 #' @references
 #' Weather data observations are retrieved from:
-#' Australian Bureau of Meteorology (BOM) Weather Data Services,
-#' Observations - individual stations: \cr
+#' Australian Bureau of Meteorology (\acronym{BOM}) Weather Data Services,
+#' Observations - individual stations: 
 #' \url{http://www.bom.gov.au/catalogue/data-feeds.shtml}
 #'
 #' Station location and other metadata are sourced from the Australian Bureau of
-#' Meteorology (BOM) webpage, Bureau of Meteorology Site Numbers: \cr
+#' Meteorology (\acronym{BOM}) webpage, Bureau of Meteorology Site Numbers: 
 #' \url{http://www.bom.gov.au/climate/cdo/about/site-num.shtml}
 #'
 #' @author Hugh Parsonage, \email{hugh.parsonage@@gmail.com}
@@ -64,10 +65,9 @@
 #' @importFrom data.table %chin%
 #' @importFrom data.table setnames
 #' @rdname get_current_weather
-#' @rdname get_current
 #' @export get_current_weather
 
-get_current_weather <- get_current <-
+get_current_weather <- 
   function(station_name,
            strict = FALSE,
            latlon = NULL,
